using System;
using System.Diagnostics;

namespace CSF.MySQL.TraceIssue
{
    public class MalfunctioningTraceProvider : ITraceProvider
    {
        #region constants

        private const string
            TRACE_SOURCE_NAME = "mysql",
            TRACE_SWITCH_LEVEL = "Verbose";

        #endregion

        #region fields

        private TraceSource _source;
        private SourceSwitch _switch;
        private DetectingTraceListener _listener;

        #endregion

        #region methods

        public void SetupTracing()
        {
            _source = new TraceSource(TRACE_SOURCE_NAME);
            _switch = new SourceSwitch("My switch", TRACE_SWITCH_LEVEL);
            _listener = new DetectingTraceListener() { Name = "Detecting" };

            TraceListener consoleListener = new ConsoleTraceListener() { Name = "Console" };

            _source.Switch = _switch;
            _source.Listeners.Clear();
            _source.Listeners.Add(_listener);
            _source.Listeners.Add(consoleListener);
        }

        public void VerifyReceivedTraceData()
        {
            if(_listener == null)
            {
                throw new InvalidOperationException("Trace listener must not be null.");
            }

            if(!_listener.HasReceivedInput)
            {
                throw new Exception("** TEST FAILED **  The trace listener has not received any data from the trace " +
                                    "source, despite executing a SQL query that triggered warnings.");
            }
        }

        #endregion
    }
}

