using System;
using System.Data;

namespace CSF.MySQL.TraceIssue
{
    public class TestCase
    {
        #region constants

        private const string
            SQL_THAT_TRIGGERS_WARNING = @"
DROP TABLE IF EXISTS `test`;
CREATE TABLE `test` ( `decimal_column` NUMERIC(4,2) NOT NULL ) ENGINE=InnoDB;
INSERT INTO `test` (`decimal_column`)
VALUES (12.3456);";

        #endregion

        #region fields

        private ConnectionCreator _connectionCreator;
        private ITraceProvider _traceProvider;

        #endregion

        #region methods

        public void ExecuteTest()
        {
            _traceProvider.SetupTracing();

            using(var conn = _connectionCreator.CreateConnection())
            {
                conn.Open();

                using(var command = conn.CreateCommand())
                {
                    command.CommandText = SQL_THAT_TRIGGERS_WARNING;
                    command.ExecuteNonQuery();
                }
            }

            // If the trace provider received no trace data then this line throws an exception.
            _traceProvider.VerifyReceivedTraceData();

            Console.WriteLine ("** TEST PASSED ** The trace listener received data (which we can only assume came " +
                               "from the warning that the SQL statement generated).");
        }

        #endregion

        #region constructor

        public TestCase(ConnectionCreator connectionCreator, ITraceProvider traceProvider)
        {
            if(connectionCreator == null)
            {
                throw new ArgumentNullException("connectionCreator");
            }
            if(traceProvider == null)
            {
                throw new ArgumentNullException("traceProvider");
            }

            _connectionCreator = connectionCreator;
            _traceProvider = traceProvider;
        }

        #endregion
    }
}

