using System;
using System.Diagnostics;
using MySql.Data.MySqlClient;

namespace CSF.MySQL.TraceIssue
{
    public class WorkingTraceProvider : ITraceProvider
    {
        #region constants

        private const string
            TRACE_SWITCH_LEVEL = "Verbose";

        #endregion

        #region fields

        private SourceSwitch _switch;
        private DetectingTraceListener _listener;

        #endregion

        #region methods

        public void SetupTracing()
        {
            _switch = new SourceSwitch("My switch", TRACE_SWITCH_LEVEL);
            _listener = new DetectingTraceListener() { Name = "Detecting" };

            TraceListener consoleListener = new ConsoleTraceListener() { Name = "Console" };

            MySqlTrace.Switch = _switch;
            MySqlTrace.Listeners.Clear();
            MySqlTrace.Listeners.Add(_listener);
            MySqlTrace.Listeners.Add(consoleListener);
        }

        public void VerifyReceivedTraceData()
        {
            if(_listener == null)
            {
                throw new InvalidOperationException("Trace listener must not be null.");
            }

            if(!_listener.HasReceivedInput)
            {
                throw new Exception("** TEST FAILED **  The trace listener has not received any data from the trace " +
                                    "source, despite executing a SQL query that triggered warnings.");
            }
        }

        #endregion
    }
}

